@@ -25,8 +25,6 @@
 
 __all__ = ["TaurusModelChooserTool", "TaurusImgModelChooserTool"]
 
-from builtins import bytes
-from future.utils import string_types
 
 from taurus.external.qt import Qt
 from taurus.core import TaurusElementType
@@ -430,7 +428,7 @@ class TaurusXYModelChooserTool(Qt.QAction, BaseConfigurableClass):
         for xy_name in xy_names:
             # each member of xy_names can be yname or a (xname, yname[, cname])
             # tuple
-            if isinstance(xy_name, string_types):
+            if isinstance(xy_name, str):
                 xname, yname, cname = None, xy_name, None
             else:
                 try:
