@@ -29,6 +29,8 @@ from taurus import Attribute
 from taurus.core import TaurusEventType
 from taurus.qt.qtgui.base import TaurusBaseComponent
 from pyqtgraph import PlotDataItem
+from taurus.core.util.containers import LoopList
+from .curveproperties import CURVE_COLORS
 
 
 class TaurusPlotDataItem(PlotDataItem, TaurusBaseComponent):
@@ -41,9 +43,13 @@ class TaurusPlotDataItem(PlotDataItem, TaurusBaseComponent):
                        Default=None
         :param yModel: (str) Taurus model name for ordinate values.
                        Default=None
+        :param colors: (generator) An infinite generator of QColor objects
         """
         xModel = kwargs.pop("xModel", None)
         yModel = kwargs.pop("yModel", None)
+        colors = kwargs.pop("colors", LoopList(CURVE_COLORS))
+        if "pen" not in kwargs:
+            kwargs["pen"] = next(colors)
         PlotDataItem.__init__(self, *args, **kwargs)
         TaurusBaseComponent.__init__(self, "TaurusBaseComponent")
         self._x = None
@@ -61,6 +67,7 @@ class TaurusPlotDataItem(PlotDataItem, TaurusBaseComponent):
         )
 
     def setXModel(self, xModel):
+        """Sets the taurus model for the x component"""
         if self.xModel is not None:
             self.xModel.removeListener(self)
 
@@ -72,23 +79,35 @@ class TaurusPlotDataItem(PlotDataItem, TaurusBaseComponent):
         self.xModel.addListener(self)
 
     def getXModelName(self):
+        """Returns the full name for the x component"""
         if self.xModel is None:
             return None
         else:
             return self.xModel.getFullName()
 
     def handleEvent(self, evt_src, evt_type, evt_value):
+        """Reimplemented from :class:`TaurusBaseComponent`"""
         if evt_type not in (TaurusEventType.Change, TaurusEventType.Periodic):
             return
         yModel = self.getModelObj()
         if yModel == evt_src:
             if yModel is not None:
-                self._y = evt_value.rvalue
+                try:
+                    # workaround to avoid UnitStrippedWarning (see #89)
+                    # TODO: add proper unit support to TaurusPlot
+                    self._y = evt_value.rvalue.magnitude
+                except AttributeError:
+                    self._y = evt_value.rvalue
             else:
                 self._y = None
         if self.xModel == evt_src:
             if self.xModel is not None:
-                self._x = evt_value.rvalue
+                try:
+                    # workaround to avoid UnitStrippedWarning (see #89)
+                    # TODO: add proper unit support to TaurusPlot
+                    self._x = evt_value.rvalue.magnitude
+                except AttributeError:
+                    self._x = evt_value.rvalue
             else:
                 self._x = None
         try:
@@ -97,7 +116,11 @@ class TaurusPlotDataItem(PlotDataItem, TaurusBaseComponent):
             self.debug("Could not set data. Reason: %r", e)
 
     def getOpts(self):
-        from taurus.qt.qtgui.tpg import serialize_opts
+        """
+        Returns the options for this DataItem as a serialized, pickable
+        dictionary
+        """
+        from taurus_pyqtgraph import serialize_opts
 
         return serialize_opts(copy.copy(self.opts))
 
@@ -105,7 +128,7 @@ class TaurusPlotDataItem(PlotDataItem, TaurusBaseComponent):
         # creates QPainters (QPen or QBrush) from a pickle loaded file
         # for adapt the serialized objects into PlotDataItem properties
 
-        from taurus.qt.qtgui.tpg import deserialize_opts
+        from taurus_pyqtgraph import deserialize_opts
 
         self.opts = deserialize_opts(opts)
 
@@ -119,6 +142,10 @@ class TaurusPlotDataItem(PlotDataItem, TaurusBaseComponent):
             self.opts["connect"] = "finite"
 
     def getFullModelNames(self):
+        """
+        Get the full model names for the x and y components as an
+        `(xname,yname)` tuple
+        """
         return (self.getXModelName(), self.getFullModelName())
 
 
