@@ -233,22 +233,31 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
         """Update the x and y buffers with the new data. If the new data is
         not compatible with the existing buffers, the buffers are reset
         """
+        rvalue = evt_value.rvalue
+        try:
+            # We use .magnitude here as a workaround for older pint affected by
+            # https://github.com/hgrecco/pint/issues/509
+            ntrends = numpy.size(rvalue.magnitude)
+        except AttributeError:
+            # support boolean values
+            _v = numpy.array(rvalue)
+            if _v.dtype is numpy.dtype("bool"):
+                from taurus.core.units import Quantity
+                rvalue = Quantity(_v)
+                ntrends = _v.size
+            else:
+                raise
 
-        # TODO: we use .magnitude below to avoid issue #509 in pint
-        # https://github.com/hgrecco/pint/issues/509
-
-        ntrends = numpy.size(evt_value.rvalue.magnitude)
-
-        if not self._isDataCompatible(evt_value, ntrends):
+        if not self._isDataCompatible(rvalue, ntrends):
             self._initBuffers(ntrends)
-            self._yUnits = evt_value.rvalue.units
+            self._yUnits = rvalue.units
             self._initCurves(ntrends)
 
         try:
-            self._yBuffer.append(evt_value.rvalue.to(self._yUnits).magnitude)
+            self._yBuffer.append(rvalue.to(self._yUnits).magnitude)
         except Exception as e:
             self.warning(
-                "Problem updating buffer Y (%s):%s", evt_value.rvalue, e
+                "Problem updating buffer Y (%s):%s", rvalue, e
             )
             evt_value = None
 
@@ -259,14 +268,13 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
 
         return self._xBuffer.contents(), self._yBuffer.contents()
 
-    def _isDataCompatible(self, evt_value, ntrends):
+    def _isDataCompatible(self, rvalue, ntrends):
         """
-        Check that the new evt_value is compatible with the current data in the
+        Check that the new rvalue is compatible with the current data in the
         buffers. Check shape and unit compatibility.
         """
         if self._xBuffer is None or self._yBuffer is None:
             return False
-        rvalue = evt_value.rvalue
 
         if rvalue.dimensionality != self._yUnits.dimensionality:
             return False
@@ -291,7 +299,6 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
 
         # model = evt_src if evt_src is not None else self.getModelObj()
 
-        # TODO: support boolean values from evt_value.rvalue
         if (
             evt_value is None
             or not hasattr(evt_value, "rvalue")
